---
title: 'Apple Pay로 간편하게 결제하세요! '
category: 업데이트
seo:
  title: Apple Pay로 간편하게 결제하세요!
  description: |-
    이제 포트원을 통해서도 애플페이 결제를 이용하실 수 있습니다.
    포트원을 통해 KCP, 토스페이먼츠, KG이니시스에서 제공하는 Apple pay를 바로 경험해보세요!
tags:
  - 업데이트
searchTags:
  - 간편결제
  - 애플
  - 애플페이
  - Apple pay
datetime: 2023-04-03T15:00:00.000Z
---



### **이제 포트원을 통해 Apple pay 이용이 가능합니다**

<Callout content="이제 포트원을 통해서도 애플페이 결제를 이용하실 수 있습니다.
포트원을 통해 KCP, 토스페이먼츠, KG이니시스에서 제공하는 Apple pay를 바로 경험해보세요!" />

### **\[지원 가능한 조건]**

- 지원PG사 :  KCP , (구)토스페이먼츠 , (신)토스페이먼츠, KG이니시스, (신)나이스페이먼츠
- 카드 : 현대카드 (그외 국내 발행 카드사 및 해외 발행카드 미지원)
- 결제방식 : 일반결제 (정기결제 미지원)

### **\[수수료 안내]**

- Apple pay 결제 시 추가로 부과되는 수수료는 없으며, 신용카드 결제 수수료율과 동일하게 적용 됩니다.  (기존 고객사의 경우에도 카드결제 수수료율과 동일하게 적용)

### **\[신청방법 안내]**

- 신규 고객사 : PG 서비스 가입 신청 시, 간편결제를 포함하여 신청
- 기존 고개사 : 상점관리자(신용카드사 셋팅된 MID 기준) > 이용정보 > 결제⋅부가서비스 > 이용서비스, 간편결제 변경하기를 통해 신청

### **\[Apple pay 관련 안내 사항]**

- Apple Pay는 현대 카드로만 결제 가능
- Apple Pay 결제를 지원하는 디바이스와 IOS 버전에서만 결제창에 노출됨

### <Callout title="Apple pay 서비스 가이드 바로가기 ↗︎" />
